%global _hardened_build 1

%if 0%{?rhel} >= 7 || 0%{?fedora}
%global mysqlconfdir %{_sysconfdir}/my.cnf.d
%else
%global mysqlconfdir %{_sysconfdir}/mysql/conf.d
%endif

# condor classads requires 2011 ISO C++ standard since Fedora 19
%if 0%{?rhel} >= 7 || 0%{?fedora} >= 19
%global classad_cxxflags -std=c++11
%endif

Name:           glite-lb-server
Version:        3.0.18
Release:        6%{?dist}
Summary:        gLite Logging and Bookkeeping server

License:        ASL 2.0
URL:            http://glite.cern.ch
Source:         http://scientific.zcu.cz/emi/emi.lb.server/%{name}-%{version}.tar.gz
# https://github.com/CESNET/glite-lb/commit/bfec0c4847db902c96eedbaf80b52e1b79c214ac
Patch1:         glite-lb-server-link.patch

# gssapi.h is needed explicitly for glite-lb-server, but the proper package is
# known only in glite-lbjp-common-gss-devel:
#  - gssapi from Globus (globus-gssapi-gsi-devel)
#  - gssapi from MIT Kerberos (krb5-devel)
#  - gssapi from Heimdal Kerberos
#BuildRequires: globus-gssapi-gsi-devel
BuildRequires:  glite-jobid-api-c-devel
BuildRequires:  glite-lb-common-devel
BuildRequires:  glite-lb-state-machine-devel
BuildRequires:  glite-lb-types
BuildRequires:  glite-lb-ws-interface
BuildRequires:  glite-lbjp-common-db-devel
BuildRequires:  glite-lbjp-common-gss-devel
BuildRequires:  glite-lbjp-common-gsoap-plugin-devel
BuildRequires:  glite-lbjp-common-log-devel
BuildRequires:  glite-lbjp-common-maildir-devel
BuildRequires:  glite-lbjp-common-server-bones-devel
BuildRequires:  glite-lbjp-common-trio-devel
BuildRequires:  gridsite-devel
BuildRequires:  gsoap-devel
BuildRequires:  c-ares-devel
BuildRequires:  cppunit-devel
BuildRequires:  flex
BuildRequires:  voms-devel
%if 0%{?rhel} <= 6 && ! 0%{?fedora}
BuildRequires:  classads-devel
%else
BuildRequires:  condor-classads-devel
%endif
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  expat-devel
BuildRequires:  bison
BuildRequires:  perl
BuildRequires:  perl(Getopt::Long)
BuildRequires:  perl(POSIX)
BuildRequires:  pkgconfig
Requires:       crontabs
Requires:       mysql-server%{?_isa}
Requires:       glite-lb-client-progs%{?_isa}
Requires:       glite-lb-utils%{?_isa}
Requires:       logrotate
Requires(pre):  shadow-utils
%if 0%{?rhel} >= 7 || 0%{?fedora}
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
BuildRequires:  systemd
%else
Requires(post): chkconfig
Requires(preun): chkconfig
Requires(preun): initscripts
%endif

%description
glite-lb-server is the gLite LB server. This package contains the LB server
daemon (glite-lb-bkserverd) and a tool for rebuilding server indices
(glite-lb-bkindex).


%prep
%setup -q
%patch1 -p2


%build
perl ./configure --root=/ --prefix=%{_prefix} --libdir=%{_lib} --mysqlconfdir=%{mysqlconfdir} --sysdefaultdir=%{_sysconfdir}/sysconfig
CFLAGS="%{?optflags}" CXXFLAGS="%{?optflags} %{?classad_cxxflags}" LDFLAGS="%{?__global_ldflags}" make %{?_smp_mflags}


%check
CFLAGS="%{?optflags}" CXXFLAGS="%{?optflags} %{?classad_cxxflags}" LDFLAGS="%{?__global_ldflags}" make check


%install
make install DESTDIR=%{buildroot}
%if 0%{?rhel} >= 7 || 0%{?fedora}
# preserve directory in /var/run
mkdir -p %{buildroot}%{_tmpfilesdir}
cat > %{buildroot}%{_tmpfilesdir}/glite-lb-server.conf <<EOF
d %{_localstatedir}/run/glite 0755 glite glite -
EOF
%endif
rm -f %{buildroot}%{_libdir}/*.a
rm -rvf %{buildroot}%{_docdir}
mkdir -p %{buildroot}%{_localstatedir}/lib/glite/dump
mkdir -p %{buildroot}%{_localstatedir}/lib/glite/purge
mkdir -p %{buildroot}%{_localstatedir}/log/glite
mkdir -p %{buildroot}%{_localstatedir}/run/glite


%pre
getent group glite >/dev/null || groupadd -r glite
getent passwd glite >/dev/null || useradd -r -g glite -d /var/lib/glite -c "gLite user" glite
exit 0


%post
%if 0%{?rhel} >= 7 || 0%{?fedora}
%systemd_post glite-lb-bkserverd.service
%else
/sbin/chkconfig --add glite-lb-bkserverd
if [ $1 -eq 1 ] ; then
    /sbin/chkconfig glite-lb-bkserverd off
fi
%endif


%preun
%if 0%{?rhel} >= 7 || 0%{?fedora}
%systemd_preun glite-lb-bkserverd.service
%else
if [ $1 -eq 0 ] ; then
    /sbin/service glite-lb-bkserverd stop >/dev/null 2>&1
    /sbin/chkconfig --del glite-lb-bkserverd
fi
%endif


%postun
%if 0%{?rhel} >= 7 || 0%{?fedora}
%systemd_postun_with_restart glite-lb-bkserverd.service
%else
if [ "$1" -ge "1" ] ; then
    /sbin/service glite-lb-bkserverd condrestart >/dev/null 2>&1 || :
fi
%endif


%files
%doc ChangeLog LICENSE glite-lb
%dir %attr(-, glite, glite) %{_localstatedir}/lib/glite
%dir %attr(-, glite, glite) %{_localstatedir}/lib/glite/dump
%dir %attr(-, glite, glite) %{_localstatedir}/lib/glite/purge
%dir %attr(-, glite, glite) %{_localstatedir}/log/glite
%dir %attr(-, glite, glite) %{_localstatedir}/run/glite
%dir %attr(-, glite, glite) %{_localstatedir}/spool/glite
# keep additional group permissions for locallogger directory,
# for storing data files locally by external components (like CREAM)
%dir %attr(-, glite, glite) %{_localstatedir}/spool/glite/lb-locallogger
%dir %attr(-, glite, glite) %{_localstatedir}/spool/glite/lb-notif
%dir %attr(-, glite, glite) %{_localstatedir}/spool/glite/lb-proxy
%dir %{_datadir}/glite/
%dir %{_sysconfdir}/glite-lb/
%config(noreplace) %{_sysconfdir}/cron.d/%{name}-*
%config(noreplace) %{_sysconfdir}/glite-lb/*
%config(noreplace) %{_sysconfdir}/logrotate.d/glite-lb-server
%config(noreplace) %{mysqlconfdir}/glite-lb-server.cnf
%config(noreplace missingok) %{_sysconfdir}/sysconfig/glite-lb
%if 0%{?rhel} >= 7 || 0%{?fedora}
%{_tmpfilesdir}/glite-lb-server.conf
%{_unitdir}/glite-lb-bkserverd.service
%else
%{_initrddir}/glite-lb-bkserverd
%endif
%{_bindir}/*
%{_sbindir}/*
%{_datadir}/glite/*
%{_mandir}/man1/glite-lb-mon-db.1*
%{_mandir}/man8/glite-lb-bkindex.8*
%{_mandir}/man8/glite-lb-bkserverd.8*
%{_mandir}/man8/glite-lb-setup.8*


%changelog
* Sun Jan 25 2015 František Dvořák <valtri@civ.zcu.cz> - 3.0.18-6
- Rebuilt with gsoap 2.8.21

* Sun Nov 23 2014 František Dvořák <valtri@civ.zcu.cz> - 3.0.18-5
- Rebuild with condor 8.3.1 (libclassad.so.7)
- Patch for adding missing OpenSSL libraries

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.18-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Aug 2 2014 František Dvořák <valtri@civ.zcu.cz> - 3.0.18-3
- Simplified packaging of documentation
- Keep permissions of the runtime directories from upstream

* Tue Jul 29 2014 František Dvořák <valtri@civ.zcu.cz> - 3.0.18-2
- Added logrotate and shadow-utils requires
- Minimal requirements for glite-lbjp-common-server-bones not needed in EPEL

* Sat Jun 28 2014 František Dvořák <valtri@civ.zcu.cz> - 3.0.18-1
- Initial package
